import { Component, Inject, OnInit } from '@angular/core';
import { Column } from "../../../core/models/column";
import { FormBuilder, FormGroup, ReactiveFormsModule, Validators } from "@angular/forms";
import { NzModalRef, NZ_MODAL_DATA } from "ng-zorro-antd/modal";
import { ColumnService } from "../column.service";
import { NzMessageService } from "ng-zorro-antd/message";
import { NzColDirective, NzRowDirective } from "ng-zorro-antd/grid";
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzInputDirective } from "ng-zorro-antd/input";
import { NzButtonModule } from 'ng-zorro-antd/button';

@Component({
  selector: 'app-edit-column',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    NzRowDirective,
    NzColDirective,
    NzFormModule,
    NzInputDirective,
    NzButtonModule
  ],
  templateUrl: './edit-column.component.html',
  styleUrl: './edit-column.component.scss'
})
export class EditColumnComponent implements OnInit {
  isSaving: boolean = false;
  validateForm!: FormGroup;

  constructor(
    private fb: FormBuilder,
    private modal: NzModalRef,
    private columnService: ColumnService,
    private message: NzMessageService,
    @Inject(NZ_MODAL_DATA) private data: { column: Column }
  ) {}

  ngOnInit(): void {
    this.validateForm = this.fb.group({
      id: [this.data.column.id, [Validators.required]],
      title: [this.data.column.title, [Validators.required]],
      brief: [this.data.column.brief, [Validators.required]],
      followNum: [this.data.column.followNum, [Validators.required, Validators.min(0)]],
      purchaseNum: [this.data.column.purchaseNum, [Validators.required, Validators.min(0)]]
    });
  }

  handleOk(): void {
    if (this.validateForm.valid) {
      this.isSaving = true;
      this.columnService.save(this.validateForm.value).subscribe({
        next: () => {
          this.message.success('保存成功');
          this.modal.close(true);
        },
        error: (error) => {
          this.message.error('保存失败');
          console.error('Error saving column:', error);
        },
        complete: () => {
          this.isSaving = false;
        }
      });
    } else {
      Object.values(this.validateForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  handleCancel(): void {
    this.modal.close();
  }
}
