import { Component, Inject } from '@angular/core';
import { FormBuilder, FormGroup, Validators, ReactiveFormsModule } from '@angular/forms';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzInputNumberModule } from 'ng-zorro-antd/input-number';
import { NzModalRef, NZ_MODAL_DATA } from 'ng-zorro-antd/modal';
import {ArticlePrice, Price, PriceType} from '../../../../core/models/price';
import { PriceService } from '../../price.service';
import { NzMessageService } from 'ng-zorro-antd/message';
import { NzButtonModule } from 'ng-zorro-antd/button';

@Component({
  selector: 'app-set-article-price',
  standalone: true,
  imports: [
    ReactiveFormsModule,
    NzFormModule,
    NzInputNumberModule,
    NzButtonModule
  ],
  templateUrl: './set-article-price.component.html',
  styleUrls: ['./set-article-price.component.scss']
})
export class SetArticlePriceComponent {
  editForm: FormGroup;
  article: ArticlePrice;
  priceType = PriceType;
  constructor(
    private fb: FormBuilder,
    private modalRef: NzModalRef,
    private priceService: PriceService,
    private message: NzMessageService,
    @Inject(NZ_MODAL_DATA) data: ArticlePrice
  ) {
    this.article = data;
    console.log(this.article)
    const price = data?.price?.amount || 0;
    const discount = data?.price?.discount || 1;

    this.editForm = this.fb.group({
      price: [price / 100, [Validators.required, Validators.min(0)]],
      discount: [discount, [Validators.required, Validators.min(0), Validators.max(1)]]
    });
  }

  handleOk(): void {
    if (this.editForm.valid) {
      const formValue = this.editForm.value;
      const priceData = {
        targetId:this.article.article.eventId,
        type:this.priceType.TypeArticle,
        amount: Math.round(formValue.price * 100),
        discount: formValue.discount
      };

      this.priceService.update(priceData as Price).subscribe({
        next: () => {
          this.message.success('价格更新成功');
          this.modalRef.close(true);
        },
        error: (error) => {
          this.message.error('价格更新失败');
          console.error('Error updating price:', error);
        }
      });
    }
  }

  handleCancel(): void {
    this.modalRef.close();
  }
}
